@@ -31,15 +31,23 @@ class MeQuery(MeFields, Query):
         super().__init__(conn)
         self.query = self.query.me
 
-    def select_me(self):
-        """Selects user fields."""
-        self.query.select(*self.fields(self.ds))
+    def select_me(self, fields=None):
+        """Selects user fields.
+
+        :param fields: Select specific fields.
+        :type fields: List(DSLField)
+        """
+        self.query.select(*fields or self.fields(self.ds))
         return self
 
-    def select_accounts(self):
-        """Selects users accounts."""
-        accounts = self.ds.User.accounts.args(**self.var_pagination)
-        account_nodes = self.ds.AccountConnection.nodes.select(*AccountFields.fields(self.ds))
+    def select_accounts(self, fields=None):
+        """Selects users accounts.
+
+        :param fields: Select specific fields.
+        :type fields: List(DSLField)
+        """
+        accounts = self.ds.User.accounts.args(**self.var_pagination, **self.var_ordering)
+        account_nodes = self.ds.AccountConnection.nodes.select(*fields or AccountFields.fields(self.ds))
         pagination = self.ds.AccountConnection.pageInfo.select(*self.page_fields())
 
         self.query.select(accounts.select(account_nodes).select(pagination))
