@@ -1,6 +1,6 @@
 """
-Query
-=====
+Base Query
+==========
 """
 
 from gql.dsl import DSLVariableDefinitions
@@ -21,6 +21,9 @@ class Query:
             "after": self.var.after,
             "before": self.var.before,
         }
+        self.var_ordering = {
+            "orderBy": self.var.order_by,
+        }
 
     def page_fields(self):
         """Returns a tule of PageInfo fields."""
