@@ -1,3 +1,6 @@
+from gql.dsl import DSLMetaField
+
+
 class ReportFields:
     @staticmethod
     def fields(ds):
@@ -19,17 +22,22 @@ class ReportFields:
             ds.Report.totalRows,
             ds.Report.totalWeight,
             ds.Report.typeCode,
+            DSLMetaField("__typename"),
         )
 
     @staticmethod
     def raw_trends(ds):
-        return (ds.Report.rawTrends,)
+        return (
+            ds.Report.rawTrends,
+            DSLMetaField("__typename"),
+        )
 
     @staticmethod
     def datasource_fields(ds):
         return (
             ds.Report.datasourceCode,
             ds.Report.datasourceCodeEnum,
+            DSLMetaField("__typename"),
         )
 
     @staticmethod
@@ -45,6 +53,7 @@ class ReportFields:
             ds.Segment.rawID,
             ds.Segment.updatedAt,
             ds.Segment.version,
+            DSLMetaField("__typename"),
         )
 
     @staticmethod
@@ -84,6 +93,7 @@ class ReportFields:
                 ds.ReportCategory.parentCode,
                 ds.ReportCategory.position,
             ),
+            DSLMetaField("__typename"),
             # TODO Add metricsGroupings somewhere
         )
 
@@ -97,4 +107,24 @@ class ReportTypeFields:
             ds.ReportType.name,
             ds.ReportType.position,
             ds.ReportType.rawID,
+            DSLMetaField("__typename"),
+        )
+
+
+class ReportDownloadFields:
+    @staticmethod
+    def fields(ds):
+        return (
+            ds.ReportDownload.id,
+            ds.ReportDownload.rawID,
+            ds.ReportDownload.createdAt,
+            ds.ReportDownload.fileURL,
+            ds.ReportDownload.filter,
+            ds.ReportDownload.outputType,
+            ds.ReportDownload.reportedAt,
+            ds.ReportDownload.reportingAt,
+            ds.ReportDownload.selectedMetrics,
+            ds.ReportDownload.status,
+            ds.ReportDownload.totalRows,
+            ds.ReportDownload.updatedAt,
         )
